]> git.sesse.net Git - ffmpeg/blobdiff - ffplay.c
avutil/opt: remove disabled old ABI compatibility code
[ffmpeg] / ffplay.c
index af0e199f8c2f2a4a72a387471b5dd1b0ff72c618..e1e4ccc73456f9667def51669a6f84f04748da7a 100644 (file)
--- a/ffplay.c
+++ b/ffplay.c
@@ -2824,7 +2824,7 @@ static int read_thread(void *arg)
     av_freep(&opts);
 
     if (ic->pb)
-        ic->pb->eof_reached = 0; // FIXME hack, ffplay maybe should not use url_feof() to test for the end
+        ic->pb->eof_reached = 0; // FIXME hack, ffplay maybe should not use avio_feof() to test for the end
 
     if (seek_by_bytes < 0)
         seek_by_bytes = !!(ic->iformat->flags & AVFMT_TS_DISCONT) && strcmp("ogg", ic->iformat->name);
@@ -3013,7 +3013,7 @@ static int read_thread(void *arg)
         }
         ret = av_read_frame(ic, pkt);
         if (ret < 0) {
-            if (ret == AVERROR_EOF || url_feof(ic->pb))
+            if (ret == AVERROR_EOF || avio_feof(ic->pb))
                 eof = 1;
             if (ic->pb && ic->pb->error)
                 break;